..
    Copyright (C) 2021 CERN.

    Invenio-Requests is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 2.6.0 (2023-07-13)

- transifex: update configs
- ui: fix username not appearing
- requests-ui: add rendering of new entity for external emails
- links: add customization of context vars when generating them

Version 2.5.0 (2023-06-30)

- Update translations
- Bump invenio-users-resources

Version 2.4.0 (2023-06-02)

- ui: add icons for deleted communities
- requests resolvers: add system creator

Version 2.3.0 (2023-05-05)

- resolvers: use record-based resolvers and proxies
- resolvers: use request id for resolving
- views: remove explicit service_id from register call

Version 2.2.0 (2023-04-25)

- upgrade invenio-records-resources

Version 2.1.0 (2023-04-20)

- upgrade invenio-records-resources

Version 2.0.0 (2023-03-28)

- add request search components
- add contrib label components
- refactor action components
- refactor relative time component

Version 1.3.0 (2023-03-24)

- bump invenio-records-resources to v2.0.0
- expand: call ghost method for unresolved entities

Version 1.2.0 (released 2023-03-13)

- add inclusion request type to UI support
- distinguish UI labels for request types (inclusion vs review)
- add self_html link to the resource payload

Version 1.1.1 (released 2023-03-09)

- results: add links template setter

Version 1.1.0 (released 2023-03-02)

- remove deprecated flask-babelex imports
- upgrade invenio-theme, invenio-records-resources, invenio-users-resources

Version 1.0.5 (released 2022-12-01)

- Add identity to links template expand method.

Version 1.0.4 (released 2022-11-25)

- add i18n translations.
- use centralized axios configuration.

Version 1.0.3 (released 2022-11-15)

- add `indexer_queue_name` property in service configs
- add the services and indexers in global registry

Version 1.0.2 (released 2022-11-04)

- bump invenio-records-resources version

Version 1.0.1 (released 2022-11-03)

- add mobile components styling

Version 1.0.0

- Initial public release.
